@@ -315,7 +315,7 @@ class vinex(Exchange):
                 side = 'sell'
 
         if 'status' in order:
-            if order['status'] == 10:
+            if order['status'] == 10 or order['status'] == 0:
                 status = 'open'
             elif order['status'] == 1:
                 status = 'closed'
